[vlc-devel] commit: Drop option_as_ from marquee interface. (JP Dinger )
git version control
git at videolan.org
Tue Jan 19 17:56:09 CET 2010
vlc | branch: master | JP Dinger <jpd at m2x.nl> | Tue Jan 19 17:45:53 2010 +0100| [2f05ac6cba8ca53db8391fa6a3374ad4588267e0] | committer: JP Dinger
Drop option_as_ from marquee interface.
> http://git.videolan.org/gitweb.cgi/vlc.git/?a=commit;h=2f05ac6cba8ca53db8391fa6a3374ad4588267e0
---
include/vlc/libvlc_media_player.h | 42 +++++++++++++++++-------------------
src/control/video.c | 36 ++++++++++++++-----------------
src/libvlc.sym | 8 +++---
3 files changed, 40 insertions(+), 46 deletions(-)
diff --git a/include/vlc/libvlc_media_player.h b/include/vlc/libvlc_media_player.h
index cb2f23c..c429993 100644
--- a/include/vlc/libvlc_media_player.h
+++ b/include/vlc/libvlc_media_player.h
@@ -80,7 +80,7 @@ typedef struct libvlc_rectangle_t
* Marq int options definition
*/
typedef enum libvlc_video_marquee_int_option_t {
- libvlc_marquee_Enabled = 0,
+ libvlc_marquee_Enable = 0,
libvlc_marquee_Color,
libvlc_marquee_Opacity,
libvlc_marquee_Position,
@@ -829,51 +829,49 @@ VLC_PUBLIC_API void libvlc_video_set_deinterlace( libvlc_media_player_t *,
libvlc_exception_t *);
/**
- * Get an option value (option which return an int)
+ * Get an integer option value
*
* \param p_mi libvlc media player
- * \param option marq option to get
+ * \param option marq option to get \see libvlc_video_marquee_int_option_t
* \param p_e an initialized exception pointer
*/
-VLC_PUBLIC_API int libvlc_video_get_marquee_option_as_int( libvlc_media_player_t *,
- libvlc_video_marquee_int_option_t,
- libvlc_exception_t * );
+VLC_PUBLIC_API int libvlc_video_get_marquee_int( libvlc_media_player_t *,
+ unsigned, libvlc_exception_t * );
/**
- * Get an option value (option which return a string)
+ * Get a string option value
*
* \param p_mi libvlc media player
- * \param option marq option to get
+ * \param option marq option to get \see libvlc_video_marquee_string_option_t
* \param p_e an initialized exception pointer
*/
-VLC_PUBLIC_API char *libvlc_video_get_marquee_option_as_string( libvlc_media_player_t *,
- libvlc_video_marquee_string_option_t,
- libvlc_exception_t * );
+VLC_PUBLIC_API char *libvlc_video_get_marquee_string( libvlc_media_player_t *,
+ unsigned, libvlc_exception_t * );
/**
- * Enable, disable or set a marq option (only int)
+ * Enable, disable or set an integer marq option
+ *
+ * Setting libvlc_marquee_Enable has the side effect of enabling (arg !0)
+ * or disabling (arg 0) the marq filter.
*
* \param p_mi libvlc media player
- * \param option marq option to set
+ * \param option marq option to set \see libvlc_video_marquee_int_option_t
* \param i_val marq option value
* \param p_e an initialized exception pointer
*/
-VLC_PUBLIC_API void libvlc_video_set_marquee_option_as_int( libvlc_media_player_t *,
- libvlc_video_marquee_int_option_t,
- int, libvlc_exception_t * );
+VLC_PUBLIC_API void libvlc_video_set_marquee_int( libvlc_media_player_t *,
+ unsigned, int, libvlc_exception_t * );
/**
- * Set a marq option (only string)
+ * Set a marq string option
*
* \param p_mi libvlc media player
- * \param option marq option to set
+ * \param option marq option to set \see libvlc_video_marquee_string_option_t
* \param psz_text marq option value
* \param p_e an initialized exception pointer
*/
-VLC_PUBLIC_API void libvlc_video_set_marquee_option_as_string( libvlc_media_player_t *,
- libvlc_video_marquee_string_option_t,
- const char *,
- libvlc_exception_t * );
+VLC_PUBLIC_API void libvlc_video_set_marquee_string( libvlc_media_player_t *,
+ unsigned, const char *, libvlc_exception_t * );
enum libvlc_video_logo_option_t {
libvlc_logo_enable,
diff --git a/src/libvlc.sym b/src/libvlc.sym
index 561579f..78d2878 100644
--- a/src/libvlc.sym
+++ b/src/libvlc.sym
@@ -187,8 +187,8 @@ libvlc_video_get_chapter_description
libvlc_video_get_crop_geometry
libvlc_video_get_height
libvlc_video_get_logo_int
-libvlc_video_get_marquee_option_as_int
-libvlc_video_get_marquee_option_as_string
+libvlc_video_get_marquee_int
+libvlc_video_get_marquee_string
libvlc_video_get_scale
libvlc_video_get_spu
libvlc_video_get_spu_count
@@ -205,8 +205,8 @@ libvlc_video_set_deinterlace
libvlc_video_set_key_input
libvlc_video_set_logo_int
libvlc_video_set_logo_string
-libvlc_video_set_marquee_option_as_int
-libvlc_video_set_marquee_option_as_string
+libvlc_video_set_marquee_int
+libvlc_video_set_marquee_string
libvlc_video_set_mouse_input
libvlc_video_set_scale
libvlc_video_set_spu
More information about the vlc-devel
mailing list
diff --git a/src/control/video.c b/src/control/video.c
index cb4d900..9fe1be5 100644
--- a/src/control/video.c
+++ b/src/control/video.c
@@ -706,11 +706,10 @@ static vlc_object_t *get_marquee_object( libvlc_media_player_t * p_mi )
}
/*****************************************************************************
* libvlc_video_get_marquee_option_as_int : get a marq option value
*****************************************************************************/
-int libvlc_video_get_marquee_option_as_int( libvlc_media_player_t *p_mi,
- libvlc_video_marquee_int_option_t option,
- libvlc_exception_t *p_e )
+int libvlc_video_get_marquee_int( libvlc_media_player_t *p_mi,
+ unsigned option, libvlc_exception_t *p_e )
{
const char * identifier = get_marquee_int_option_identifier(option);
if(!identifier)
@@ -721,8 +720,8 @@ int libvlc_video_get_marquee_option_as_int( libvlc_media_player_t *p_mi,
}
vlc_object_t * marquee = get_marquee_object(p_mi);
- /* Handle the libvlc_marquee_Enabled separately */
- if(option == libvlc_marquee_Enabled)
+ /* Handle the libvlc_marquee_Enable separately */
+ if(option == libvlc_marquee_Enable)
{
bool isEnabled = marquee != NULL;
vlc_object_release(marquee);
@@ -743,11 +742,10 @@ int libvlc_video_get_marquee_option_as_int( libvlc_media_player_t *p_mi,
}
/*****************************************************************************
* libvlc_video_get_marquee_option_as_string : get a marq option value
*****************************************************************************/
-char * libvlc_video_get_marquee_option_as_string( libvlc_media_player_t *p_mi,
- libvlc_video_marquee_string_option_t option,
- libvlc_exception_t *p_e )
+char * libvlc_video_get_marquee_string( libvlc_media_player_t *p_mi,
+ unsigned option, libvlc_exception_t *p_e )
{
const char * identifier = get_marquee_string_option_identifier(option);
if(!identifier)
@@ -770,11 +768,10 @@ char * libvlc_video_get_marquee_option_as_string( libvlc_media_player_t *p_mi,
}
/*****************************************************************************
* libvlc_video_set_marquee_option_as_int: enable, disable or set an int option
*****************************************************************************/
-void libvlc_video_set_marquee_option_as_int( libvlc_media_player_t *p_mi,
- libvlc_video_marquee_int_option_t option,
- int value, libvlc_exception_t *p_e )
+void libvlc_video_set_marquee_int( libvlc_media_player_t *p_mi,
+ unsigned option, int value, libvlc_exception_t *p_e )
{
const char * identifier = get_marquee_int_option_identifier(option);
if(!identifier)
@@ -784,8 +781,8 @@ void libvlc_video_set_marquee_option_as_int( libvlc_media_player_t *p_mi,
return;
}
- /* Handle the libvlc_marquee_Enabled separately */
- if(option == libvlc_marquee_Enabled)
+ /* Handle the libvlc_marquee_Enable separately */
+ if(option == libvlc_marquee_Enable)
{
libvlc_exception_t e;
libvlc_exception_init(&e);
@@ -811,11 +808,10 @@ void libvlc_video_set_marquee_option_as_int( libvlc_media_player_t *p_mi,
}
/*****************************************************************************
* libvlc_video_set_marquee_option_as_string: set a string option
*****************************************************************************/
-void libvlc_video_set_marquee_option_as_string( libvlc_media_player_t *p_mi,
- libvlc_video_marquee_string_option_t option,
- const char * value, libvlc_exception_t *p_e )
+void libvlc_video_set_marquee_string( libvlc_media_player_t *p_mi,
+ unsigned option, const char * value, libvlc_exception_t *p_e )
{
const char * identifier = get_marquee_string_option_identifier(option);
if(!identifier)
@@ -706,11 +706,10 @@ static vlc_object_t *get_marquee_object( libvlc_media_player_t * p_mi )
}
/*****************************************************************************
- * libvlc_video_get_marquee_option_as_int : get a marq option value
+ * libvlc_video_get_marquee_int : get a marq option value
*****************************************************************************/
@@ -743,11 +742,10 @@ int libvlc_video_get_marquee_option_as_int( libvlc_media_player_t *p_mi,
}
/*****************************************************************************
- * libvlc_video_get_marquee_option_as_string : get a marq option value
+ * libvlc_video_get_marquee_string : get a marq option value
*****************************************************************************/
@@ -770,11 +768,10 @@ char * libvlc_video_get_marquee_option_as_string( libvlc_media_player_t *p_mi,
}
/*****************************************************************************
- * libvlc_video_set_marquee_option_as_int: enable, disable or set an int option
+ * libvlc_video_set_marquee_int: enable, disable or set an int option
*****************************************************************************/
@@ -811,11 +808,10 @@ void libvlc_video_set_marquee_option_as_int( libvlc_media_player_t *p_mi,
}
/*****************************************************************************
- * libvlc_video_set_marquee_option_as_string: set a string option
+ * libvlc_video_set_marquee_string: set a string option
*****************************************************************************/